pub struct MatchDB {
pub conn: Connection,
pub cards_database: CardsDatabase,
}Fields
conn: Connectioncards_database: CardsDatabaseImplementations
Sourceimpl MatchDB
impl MatchDB
pub fn new(conn: Connection, cards_database: CardsDatabase) -> Self
Sourcepub fn init(&mut self) -> Result<()>
pub fn init(&mut self) -> Result<()>
Errors
will return an error if the database cannot be contacted for some reason or if the migrations cannot be applied
Sourcepub fn execute(
&mut self,
query: &str,
params: impl RusqliteParams,
) -> RusqliteResult<usize>
pub fn execute( &mut self, query: &str, params: impl RusqliteParams, ) -> RusqliteResult<usize>
Errors
passes along errors from Rusqlite
Sourcepub fn get_match_results(&mut self, match_id: &str) -> Result<Vec<MatchResult>>
pub fn get_match_results(&mut self, match_id: &str) -> Result<Vec<MatchResult>>
Errors
will return an error if the database cannot be contacted for some reason
Sourcepub fn get_decklists(&mut self, match_id: &str) -> Result<Vec<Deck>>
pub fn get_decklists(&mut self, match_id: &str) -> Result<Vec<Deck>>
Errors
will return an error if the database cannot be contacted for some reason
Sourcepub fn get_mulligans(&mut self, match_id: &str) -> Result<Vec<Mulligan>>
pub fn get_mulligans(&mut self, match_id: &str) -> Result<Vec<Mulligan>>
Errors
will return an error if the database cannot be contacted for some reason